@@ -40,7 +40,7 @@ use SNMP::Info::Layer3;
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE 
             $int_include_vpn $fake_idx $type_class/;
 
-$VERSION = '2.11';
+$VERSION = '3.00_003';
 
 %MIBS = (
             %SNMP::Info::Layer3::MIBS,
@@ -152,10 +152,6 @@ sub os {
     return 'altiga';
 }
 
-sub hasCDP {
-    return 0;
-}
-
 # $altiga->interfaces() - Map the Interfaces to their physical names
 # Add interface number to interface name to prevent duplicate ifDescr
 # Included statically configured VPN tunnels if ($int_include_vpn)
@@ -350,10 +346,6 @@ Tries to determine OS version from the C<sysDescr.0> field. Returns version or C
 
 Combines results from C<fan1_alarm>, C<fan2_alarm>, and C<fam3_alarm> methods.
 
-=item $altiga->hasCDP()
-
-No.
-
 =item $altiga->ps1_status()
 
 Combines C<ps1_3v_alarm> and C<ps1_5v_alarm> methods.
