@@ -42,7 +42,7 @@ use SNMP::Info::LLDP;
 
 use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
 
-$VERSION = '2.11';
+$VERSION = '3.00_003';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -196,134 +196,6 @@ sub interfaces {
     return $i_descr;
 }
 
-#  Use FDP and/or LLDP
-
-sub hasCDP {
-    my $hp9300 = shift;
-
-    return $hp9300->hasLLDP() || $hp9300->SUPER::hasCDP();
-}
-
-sub c_ip {
-    my $hp9300  = shift;
-    my $partial = shift;
-
-    my $cdp  = $hp9300->SUPER::c_ip($partial) || {};
-    my $lldp = $hp9300->lldp_ip($partial)     || {};
-
-    my %c_ip;
-    foreach my $iid ( keys %$cdp ) {
-        my $ip = $cdp->{$iid};
-        next unless defined $ip;
-
-        $c_ip{$iid} = $ip;
-    }
-
-    foreach my $iid ( keys %$lldp ) {
-        my $ip = $lldp->{$iid};
-        next unless defined $ip;
-
-        $c_ip{$iid} = $ip;
-    }
-    return \%c_ip;
-}
-
-sub c_if {
-    my $hp9300  = shift;
-    my $partial = shift;
-
-    my $lldp = $hp9300->lldp_if($partial)     || {};
-    my $cdp  = $hp9300->SUPER::c_if($partial) || {};
-
-    my %c_if;
-    foreach my $iid ( keys %$cdp ) {
-        my $if = $cdp->{$iid};
-        next unless defined $if;
-
-        $c_if{$iid} = $if;
-    }
-
-    foreach my $iid ( keys %$lldp ) {
-        my $if = $lldp->{$iid};
-        next unless defined $if;
-
-        $c_if{$iid} = $if;
-    }
-    return \%c_if;
-}
-
-sub c_port {
-    my $hp9300  = shift;
-    my $partial = shift;
-
-    my $lldp = $hp9300->lldp_port($partial)     || {};
-    my $cdp  = $hp9300->SUPER::c_port($partial) || {};
-
-    my %c_port;
-    foreach my $iid ( keys %$cdp ) {
-        my $port = $cdp->{$iid};
-        next unless defined $port;
-
-        $c_port{$iid} = $port;
-    }
-
-    foreach my $iid ( keys %$lldp ) {
-        my $port = $lldp->{$iid};
-        next unless defined $port;
-
-        $c_port{$iid} = $port;
-    }
-    return \%c_port;
-}
-
-sub c_id {
-    my $hp9300  = shift;
-    my $partial = shift;
-
-    my $lldp = $hp9300->lldp_id($partial)     || {};
-    my $cdp  = $hp9300->SUPER::c_id($partial) || {};
-
-    my %c_id;
-    foreach my $iid ( keys %$cdp ) {
-        my $id = $cdp->{$iid};
-        next unless defined $id;
-
-        $c_id{$iid} = $id;
-    }
-
-    foreach my $iid ( keys %$lldp ) {
-        my $id = $lldp->{$iid};
-        next unless defined $id;
-
-        $c_id{$iid} = $id;
-    }
-    return \%c_id;
-}
-
-sub c_platform {
-    my $hp9300  = shift;
-    my $partial = shift;
-
-    my $lldp = $hp9300->lldp_rem_sysdesc($partial)  || {};
-    my $cdp  = $hp9300->SUPER::c_platform($partial) || {};
-
-    my %c_platform;
-    foreach my $iid ( keys %$cdp ) {
-        my $platform = $cdp->{$iid};
-        next unless defined $platform;
-
-        $c_platform{$iid} = $platform;
-    }
-
-    foreach my $iid ( keys %$lldp ) {
-        my $platform = $lldp->{$iid};
-        next unless defined $platform;
-
-        $c_platform{$iid} = $platform;
-    }
-    return \%c_platform;
-}
-
 1;
 __END__
 
@@ -527,54 +399,6 @@ Returns reference to hash.  Current Port Speed.
 
 =back
 
-=head2 Topology information
-
-Based upon the software version devices may support Foundry Discovery
-Protocol (FDP) and Link Layer Discovery Protocol (LLDP). These
-methods will query both and return the combination of all information. As a
-result, there may be identical topology information returned from the two
-protocols causing duplicate entries.  It is the calling program's
-responsibility to identify any duplicate entries and remove duplicates
-if necessary.
-
-=over
-
-=item $hp9300->hasCDP()
-
-Returns true if the device is running either FDP or LLDP.
-
-=item $hp9300->c_if()
-
-Returns reference to hash.  Key: iid Value: local device port (interfaces)
-
-=item $hp9300->c_ip()
-
-Returns reference to hash.  Key: iid Value: remote IPv4 address
-
-If multiple entries exist with the same local port, c_if(), with the same IPv4
-address, c_ip(), it may be a duplicate entry.
-
-If multiple entries exist with the same local port, c_if(), with different
-IPv4 addresses, c_ip(), there is either a non-FDP/LLDP device in between two
-or more devices or multiple devices which are not directly connected.  
-
-Use the data from the Layer2 Topology Table below to dig deeper.
-
-=item $hp9300->c_port()
-
-Returns reference to hash. Key: iid Value: remote port (interfaces)
-
-=item $hp9300->c_id()
-
-Returns reference to hash. Key: iid Value: string value used to identify the
-chassis component associated with the remote system.
-
-=item $hp9300->c_platform()
-
-Returns reference to hash.  Key: iid Value: Remote Device Type
-
-=back
-
 =head2 Table Methods imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
