@@ -39,7 +39,7 @@ use SNMP::Info::Layer3;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '2.11';
+$VERSION = '3.00_003';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -175,7 +175,7 @@ These are methods that return scalar value from SNMP
 
 =item $pfront->vendor()
 
-Returns 'packetfront'.
+Returns C<'packetfront'>.
 
 =item $pfront->os()
 
@@ -187,7 +187,7 @@ Returns the software version extracted from C<sysDescr>.
 
 =item $pfront->serial()
 
-Returns the value of productSerialNo. 
+Returns the value of C<productSerialNo>. 
 
 =back
 
